izitest - An easy test suite
============================

.. image:: https://img.shields.io/github/license/nhqml/izitest
   :target: https://github.com/Nhqml/izitest/blob/master/LICENSE

.. image:: https://img.shields.io/pypi/v/izitest
   :target: https://pypi.org/project/izitest/

.. image:: https://img.shields.io/pypi/status/izitest

.. image:: https://img.shields.io/readthedocs/izitest
   :target: https://izitest.rtfd.io

WIP... please be patient.
